@@ -8,6 +8,8 @@
 #ifndef BTLLIB_NTHASH_HPP
 #define BTLLIB_NTHASH_HPP
 
+#include "status.hpp"
+
 #include <cstdint>
 #include <limits>
 #include <string>
@@ -522,10 +524,12 @@ ntf64(const char* kmer_seq, const unsigned k)
       16 * CONVERT_TAB[(unsigned char)kmer_seq[k - 3]] + // NOLINT
       4 * CONVERT_TAB[(unsigned char)kmer_seq[k - 2]] +
       CONVERT_TAB[(unsigned char)kmer_seq[k - 1]];
+    // cppcheck-suppress arrayIndexOutOfBounds
     h_val ^= TRIMER_TAB[trimer_loc];
   } else if (remainder == 2) {
     uint8_t dimer_loc = 4 * CONVERT_TAB[(unsigned char)kmer_seq[k - 2]] +
                         CONVERT_TAB[(unsigned char)kmer_seq[k - 1]];
+    // cppcheck-suppress arrayIndexOutOfBounds
     h_val ^= DIMER_TAB[dimer_loc];
   } else if (remainder == 1) {
     h_val ^= SEED_TAB[(unsigned char)kmer_seq[k - 1]];
@@ -544,10 +548,12 @@ ntr64(const char* kmer_seq, const unsigned k)
       16 * RC_CONVERT_TAB[(unsigned char)kmer_seq[k - 1]] + // NOLINT
       4 * RC_CONVERT_TAB[(unsigned char)kmer_seq[k - 2]] +
       RC_CONVERT_TAB[(unsigned char)kmer_seq[k - 3]];
+    // cppcheck-suppress arrayIndexOutOfBounds
     h_val ^= TRIMER_TAB[trimer_loc];
   } else if (remainder == 2) {
     uint8_t dimer_loc = 4 * RC_CONVERT_TAB[(unsigned char)kmer_seq[k - 1]] +
                         RC_CONVERT_TAB[(unsigned char)kmer_seq[k - 2]];
+    // cppcheck-suppress arrayIndexOutOfBounds
     h_val ^= DIMER_TAB[dimer_loc];
   } else if (remainder == 1) {
     h_val ^= SEED_TAB[(unsigned char)kmer_seq[k - 1] & CP_OFF];
@@ -1204,9 +1210,9 @@ ntmsm64(const char* kmer_seq,
                  MS_TAB_33R[(unsigned char)kmer_seq[seed_pos] & CP_OFF]
                            [seed_pos % 33]); // NOLINT
     }
-    h_val[j * m2] = rs_val < fs_val ? rs_val : fs_val;
+    h_val[size_t(j) * m2] = rs_val < fs_val ? rs_val : fs_val;
     for (unsigned j2 = 1; j2 < m2; j2++) {
-      uint64_t t_val = h_val[j * m2] * (j2 ^ k * MULTISEED);
+      uint64_t t_val = h_val[size_t(j) * m2] * (j2 ^ k * MULTISEED);
       t_val ^= t_val >> MULTISHIFT;
       h_val[j * m2 + j2] = t_val;
     }
@@ -1241,9 +1247,9 @@ ntmsm64(const char* kmer_seq,
                  MS_TAB_33R[(unsigned char)kmer_seq[seed_pos] & CP_OFF]
                            [seed_pos % 33]); // NOLINT
     }
-    h_val[j * m2] = rs_val < fs_val ? rs_val : fs_val;
+    h_val[size_t(j) * m2] = rs_val < fs_val ? rs_val : fs_val;
     for (unsigned j2 = 1; j2 < m2; j2++) {
-      uint64_t t_val = h_val[j * m2] * (j2 ^ k * MULTISEED);
+      uint64_t t_val = h_val[size_t(j) * m2] * (j2 ^ k * MULTISEED);
       t_val ^= t_val >> MULTISHIFT;
       h_val[j * m2 + j2] = t_val;
     }
@@ -1256,41 +1262,43 @@ using SpacedSeed = std::vector<unsigned>;
 static std::vector<SpacedSeed>
 parse_seeds(const std::vector<std::string>& seed_strings);
 
-/**
- * Iterate over hash values for k-mers in a
- * given DNA sequence.
- *
- * This implementation uses ntHash
- * function to efficiently calculate
- * hash values for successive k-mers.
- */
 class NtHash
 {
 
 public:
   /**
    * Constructor.
-   * @param seq DNA sequence to be hashed
-   * @param seq_len length of seq
-   * @param k k-mer size
-   * @param hash_num number of hashes
+   * @param seq C string of DNA sequence to be hashed.
+   * @param seq_len Length of seq.
+   * @param hash_num Number of hashes to produce per k-mer.
+   * @param k K-mer size.
+   * @param pos Position in seq to start hashing from.
    */
   NtHash(const char* seq,
          size_t seq_len,
-         unsigned k,
          unsigned hash_num,
+         unsigned k,
          size_t pos = 0);
 
   /**
    * Constructor.
-   * @param seq DNA sequence to be hashed
-   * @param k k-mer size
-   * @param hash_num number of hashes
+   * @param seq String of DNA sequence to be hashed.
+   * @param hash_num Number of hashes to produce per k-mer.
+   * @param k K-mer size.
+   * @param pos Position in seq to start hashing from.
    */
-  NtHash(const std::string& seq, unsigned k, unsigned hash_num, size_t pos = 0);
+  NtHash(const std::string& seq, unsigned hash_num, unsigned k, size_t pos = 0);
 
   /**
-   * Calculate the next hash value
+   * Calculate the hash values of current k-mer and advance to the next k-mer.
+   * NtHash advances one nucleotide at a time until it finds a k-mer with valid
+   * characters (ACTG) and skips over those with invalid characters (non-ACTG,
+   * including N). This method must be called before hashes() is accessed, for
+   * the first and every subsequent hashed kmer. get_pos() may be called at any
+   * time to obtain the position of last hashed k-mer or the k-mer to be hashed
+   * if roll() has never been called on this NtHash object. It is important to
+   * note that the number of roll() calls is NOT necessarily equal to get_pos(),
+   * if there are N or invalid characters in the hashed sequence.
    * @return true on success and false otherwise
    */
   bool roll();
@@ -1300,10 +1308,17 @@ public:
 
   const uint64_t* hashes() const { return hashes_vector.data(); }
 
+  /**
+   * Get the position of last hashed k-mer or the k-mer to be hashed if roll()
+   * has never been called on this NtHash object.
+   */
   size_t get_pos() const { return pos; }
   bool forward() const { return forward_hash <= reverse_hash; }
-  unsigned get_k() const { return k; }
   unsigned get_hash_num() const { return hash_num; }
+  unsigned get_k() const { return k; }
+
+  uint64_t get_forward_hash() const { return forward_hash; }
+  uint64_t get_reverse_hash() const { return reverse_hash; }
 
 private:
   friend class SeedNtHash;
@@ -1313,8 +1328,8 @@ private:
 
   const char* seq;
   const size_t seq_len;
-  const unsigned k;
   const unsigned hash_num;
+  const unsigned k;
   size_t pos;
   bool initialized;
   std::vector<uint64_t> hashes_vector;
@@ -1328,36 +1343,43 @@ class SeedNtHash
 public:
   SeedNtHash(const char* seq,
              size_t seq_len,
-             unsigned k,
              const std::vector<SpacedSeed>& seeds,
              unsigned hash_num_per_seed,
+             unsigned k,
              size_t pos = 0);
   SeedNtHash(const std::string& seq,
-             unsigned k,
              const std::vector<SpacedSeed>& seeds,
              unsigned hash_num_per_seed,
+             unsigned k,
              size_t pos = 0);
   SeedNtHash(const char* seq,
              size_t seq_len,
-             unsigned k,
              const std::vector<std::string>& seeds,
              unsigned hash_num_per_seed,
+             unsigned k,
              size_t pos = 0);
   SeedNtHash(const std::string& seq,
-             unsigned k,
              const std::vector<std::string>& seeds,
              unsigned hash_num_per_seed,
+             unsigned k,
              size_t pos = 0);
 
+  /**
+   * Calculate the next hash value.
+   * @return true on success and false otherwise
+   */
+  bool roll();
+
   const uint64_t* hashes() const { return nthash.hashes(); }
 
   size_t get_pos() const { return nthash.get_pos(); }
   bool forward() const { return nthash.forward(); }
-  unsigned get_k() const { return nthash.get_k(); }
   unsigned get_hash_num() const { return nthash.get_hash_num(); }
   unsigned get_hash_num_per_seed() const { return hash_num_per_seed; }
+  unsigned get_k() const { return nthash.get_k(); }
 
-  bool roll();
+  uint64_t get_forward_hash() const { return nthash.get_forward_hash(); }
+  uint64_t get_reverse_hash() const { return nthash.get_reverse_hash(); }
 
 private:
   bool init();
@@ -1369,64 +1391,68 @@ private:
 
 inline NtHash::NtHash(const char* seq,
                       size_t seq_len,
-                      unsigned k,
                       unsigned hash_num,
+                      unsigned k,
                       size_t pos)
   : seq(seq)
   , seq_len(seq_len)
-  , k(k)
   , hash_num(hash_num)
+  , k(k)
   , pos(pos)
   , initialized(false)
 {
+  check_warning(hash_num >= k,
+                "NtHash: using " + std::to_string(hash_num) +
+                  " hash functions and k size of " + std::to_string(k) +
+                  ". Did you permute the parameters?");
   hashes_vector.resize(hash_num);
 }
 
 inline NtHash::NtHash(const std::string& seq,
-                      unsigned k,
                       unsigned hash_num,
+                      unsigned k,
                       size_t pos)
-  : NtHash(seq.c_str(), seq.size(), k, hash_num, pos)
+  : NtHash(seq.c_str(), seq.size(), hash_num, k, pos)
 {}
 
 inline SeedNtHash::SeedNtHash(const char* seq,
                               size_t seq_len,
-                              unsigned k,
                               const std::vector<SpacedSeed>& seeds,
                               unsigned hash_num_per_seed,
+                              unsigned k,
                               size_t pos)
-  : nthash(seq, seq_len, k, seeds.size() * hash_num_per_seed, pos)
+  : nthash(seq, seq_len, seeds.size() * hash_num_per_seed, k, pos)
   , hash_num_per_seed(hash_num_per_seed)
   , seeds(seeds)
 {}
 
 inline SeedNtHash::SeedNtHash(const std::string& seq,
-                              unsigned k,
                               const std::vector<SpacedSeed>& seeds,
                               unsigned hash_num_per_seed,
+                              unsigned k,
                               size_t pos)
-  : nthash(seq, k, seeds.size() * hash_num_per_seed, pos)
+  : nthash(seq, seeds.size() * hash_num_per_seed, k, pos)
   , hash_num_per_seed(hash_num_per_seed)
   , seeds(seeds)
 {}
 
 inline SeedNtHash::SeedNtHash(const char* seq,
                               size_t seq_len,
-                              unsigned k,
                               const std::vector<std::string>& seeds,
                               unsigned hash_num_per_seed,
+                              unsigned k,
                               size_t pos)
-  : nthash(seq, seq_len, k, seeds.size() * hash_num_per_seed, pos)
+  : nthash(seq, seq_len, seeds.size() * hash_num_per_seed, k, pos)
   , hash_num_per_seed(hash_num_per_seed)
   , seeds(parse_seeds(seeds))
 {}
 
 inline SeedNtHash::SeedNtHash(const std::string& seq,
-                              unsigned k,
                               const std::vector<std::string>& seeds,
                               unsigned hash_num_per_seed,
+                              unsigned k,
                               size_t pos)
-  : nthash(seq, k, seeds.size() * hash_num_per_seed, pos)
+  : nthash(seq, seeds.size() * hash_num_per_seed, k, pos)
   , hash_num_per_seed(hash_num_per_seed)
   , seeds(parse_seeds(seeds))
 {}
@@ -1464,7 +1490,7 @@ NtHash::sub(const std::vector<unsigned>& positions,
 }
 
 // NOLINTNEXTLINE
-#define NTHASH_INIT(CLASS, NTHASH_CALL, MEMBER_PREFIX)                         \
+#define BTLLIB_NTHASH_INIT(CLASS, NTHASH_CALL, MEMBER_PREFIX)                  \
   inline bool CLASS::init()                                                    \
   {                                                                            \
     if (MEMBER_PREFIX k > MEMBER_PREFIX seq_len) {                             \
@@ -1486,7 +1512,7 @@ NtHash::sub(const std::vector<unsigned>& positions,
   }
 
 // NOLINTNEXTLINE
-#define NTHASH_ROLL(CLASS, NTHASH_CALL, MEMBER_PREFIX)                         \
+#define BTLLIB_NTHASH_ROLL(CLASS, NTHASH_CALL, MEMBER_PREFIX)                  \
   inline bool CLASS::roll()                                                    \
   {                                                                            \
     if (!MEMBER_PREFIX initialized) {                                          \
@@ -1506,49 +1532,49 @@ NtHash::sub(const std::vector<unsigned>& positions,
     return true;                                                               \
   }
 
-NTHASH_INIT(NtHash,
-            ntmc64(seq + pos,
-                   k,
-                   hash_num,
-                   forward_hash,
-                   reverse_hash,
-                   posN,
-                   hashes_vector.data()), )
-NTHASH_ROLL(NtHash,
-            ntmc64(seq[pos - 1],
-                   seq[pos - 1 + k],
-                   k,
-                   hash_num,
-                   forward_hash,
-                   reverse_hash,
-                   hashes_vector.data()), )
+BTLLIB_NTHASH_INIT(NtHash,
+                   ntmc64(seq + pos,
+                          k,
+                          hash_num,
+                          forward_hash,
+                          reverse_hash,
+                          posN,
+                          hashes_vector.data()), )
+BTLLIB_NTHASH_ROLL(NtHash,
+                   ntmc64(seq[pos - 1],
+                          seq[pos - 1 + k],
+                          k,
+                          hash_num,
+                          forward_hash,
+                          reverse_hash,
+                          hashes_vector.data()), )
 
-NTHASH_INIT(SeedNtHash,
-            ntmsm64(nthash.seq + nthash.pos,
-                    seeds,
-                    nthash.k,
-                    seeds.size(),
-                    hash_num_per_seed,
-                    nthash.forward_hash,
-                    nthash.reverse_hash,
-                    posN,
-                    nthash.hashes_vector.data()),
-            nthash.)
-NTHASH_ROLL(SeedNtHash,
-            ntmsm64(nthash.seq + nthash.pos,
-                    seeds,
-                    nthash.seq[nthash.pos - 1],
-                    nthash.seq[nthash.pos - 1 + nthash.k],
-                    nthash.k,
-                    seeds.size(),
-                    hash_num_per_seed,
-                    nthash.forward_hash,
-                    nthash.reverse_hash,
-                    nthash.hashes_vector.data()),
-            nthash.)
+BTLLIB_NTHASH_INIT(SeedNtHash,
+                   ntmsm64(nthash.seq + nthash.pos,
+                           seeds,
+                           nthash.k,
+                           seeds.size(),
+                           hash_num_per_seed,
+                           nthash.forward_hash,
+                           nthash.reverse_hash,
+                           posN,
+                           nthash.hashes_vector.data()),
+                   nthash.)
+BTLLIB_NTHASH_ROLL(SeedNtHash,
+                   ntmsm64(nthash.seq + nthash.pos,
+                           seeds,
+                           nthash.seq[nthash.pos - 1],
+                           nthash.seq[nthash.pos - 1 + nthash.k],
+                           nthash.k,
+                           seeds.size(),
+                           hash_num_per_seed,
+                           nthash.forward_hash,
+                           nthash.reverse_hash,
+                           nthash.hashes_vector.data()),
+                   nthash.)
 
-#undef NTHASH_INIT
-#undef NTHASH_ROLL
+#undef BTLLIB_NTHASH_INIT
+#undef BTLLIB_NTHASH_ROLL
 
 } // namespace btllib
 
