@@ -4,6 +4,8 @@
 #ifndef BTLLIB_UTIL_HPP
 #define BTLLIB_UTIL_HPP
 
+#include "cstring.hpp"
+
 #include <algorithm>
 #include <string>
 #include <vector>
@@ -12,16 +14,24 @@ namespace btllib {
 
 inline std::vector<std::string>
 split(const std::string& s, const std::string& delim);
+inline std::string
+join(const std::vector<std::string>& s, const std::string& delim);
 inline void
 ltrim(std::string& s);
 inline void
+ltrim(CString& s);
+inline void
 rtrim(std::string& s);
 inline void
+rtrim(CString& s);
+inline void
 trim(std::string& s);
+inline void
+trim(CString& s);
 inline bool
-starts_with(std::string s, std::string prefix);
+startswith(std::string s, std::string prefix);
 inline bool
-ends_with(std::string s, std::string suffix);
+endswith(std::string s, std::string suffix);
 
 inline std::vector<std::string>
 split(const std::string& s, const std::string& delim)
@@ -37,6 +47,17 @@ split(const std::string& s, const std::string& delim)
   return tokens;
 }
 
+inline std::string
+join(const std::vector<std::string>& s, const std::string& delim)
+{
+  std::string joined = s[0];
+  for (size_t i = 1; i < s.size(); i++) {
+    joined += delim;
+    joined += s[i];
+  }
+  return joined;
+}
+
 inline void
 ltrim(std::string& s)
 {
@@ -45,6 +66,16 @@ ltrim(std::string& s)
           }));
 }
 
+inline void
+ltrim(CString& s)
+{
+  decltype(s.size()) i = 0;
+  while (i < s.size() && bool(std::isspace(s[i]))) {
+    i++;
+  }
+  s.erase(0, i);
+}
+
 inline void
 rtrim(std::string& s)
 {
@@ -55,6 +86,16 @@ rtrim(std::string& s)
           s.end());
 }
 
+inline void
+rtrim(CString& s)
+{
+  auto i = s.size();
+  while (i > 0 && bool(std::isspace(s[i - 1]))) {
+    i--;
+  }
+  s.resize(i);
+}
+
 inline void
 trim(std::string& s)
 {
@@ -62,8 +103,15 @@ trim(std::string& s)
   rtrim(s);
 }
 
+inline void
+trim(CString& s)
+{
+  ltrim(s);
+  rtrim(s);
+}
+
 inline bool
-starts_with(std::string s, std::string prefix)
+startswith(std::string s, std::string prefix)
 {
   std::transform(s.begin(), s.end(), s.begin(), ::tolower);
   std::transform(prefix.begin(), prefix.end(), prefix.begin(), ::tolower);
@@ -71,7 +119,7 @@ starts_with(std::string s, std::string prefix)
 }
 
 inline bool
-ends_with(std::string s, std::string suffix)
+endswith(std::string s, std::string suffix)
 {
   std::transform(s.begin(), s.end(), s.begin(), ::tolower);
   std::transform(suffix.begin(), suffix.end(), suffix.begin(), ::tolower);
